@@ -7,15 +7,16 @@ package Tk::DirTree;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = sprintf '4.%03d', q$Revision: #14 $ =~ /\D(\d+)\s*$/;
+$VERSION = '4.015';
 
 use Tk;
 use Tk::Derived;
 use Tk::Tree;
 use Cwd;
 use DirHandle;
+use File::Spec qw();
 
-use base  qw(Tk::Widget Tk::Derived Tk::Tree);
+use base  qw(Tk::Derived Tk::Tree);
 use strict;
 
 Construct Tk::Widget 'DirTree';
@@ -90,8 +91,7 @@ sub set_dir {
     foreach my $name (split( /[\/\\]/, $fulldir )) {
         next unless length $name;
         push @dirs, $name;
-        my $dir = join( '/', @dirs );
-	$dir =~ s|^//|/|;
+	my $dir = File::Spec->catfile( '/', @dirs );
         $w->add_to_tree( $dir, $name, $parent )
             unless $w->infoExists( $dir );
         $parent = $dir;
@@ -107,10 +107,9 @@ sub OpenCmd {
     my( $w, $dir ) = @_;
 
     my $parent = $dir;
-    $dir = '' if $dir eq '/';
     foreach my $name ($w->dirnames( $parent )) {
         next if ($name eq '.' || $name eq '..');
-        my $subdir = "$dir/$name";
+        my $subdir = File::Spec->catfile( $dir, $name );
         next unless -d $subdir;
         if( $w->infoExists( $subdir ) ) {
             $w->show( -entry => $subdir );
@@ -151,7 +150,7 @@ sub has_subdir {
     foreach my $name ($w->dirnames( $dir )) {
         next if ($name eq '.' || $name eq '..');
         next if ($name =~ /^\.+$/);
-        return( 1 ) if -d "$dir/$name";
+        return( 1 ) if -d File::Spec->catfile( $dir, $name );
     }
     return( 0 );
 }
@@ -196,9 +195,6 @@ sub dirnames {
 			  -exportselection => 1,
 			  -browsecmd => sub {
 			      $w->{curr_dir} = shift;
-			      if ($^O ne 'MSWin32') {
-				  $w->{curr_dir} =~ s|^//|/|; # bugfix
-			      }
 			  },
 
 			  # With this version of -command a double-click will
